@@ -15,7 +15,7 @@ let window = make_window_from_structure window_structure "Hello world window"
      All the widgets are [#show]ed except the window itself, so it is
      still time to initialize things before displaying it *)
        
-let _ = window #connect_delete_event( fun () -> Gtk.main_quit(); false )
+let _ = window #connect_delete_event( fun () -> GtkThr.main_quit(); false )
   (* The handler installed with the method [#connect_delete_event]
      is called when the user tries to close the window.  *)
 
