@@ -22,13 +22,13 @@ let window_structure =
 
 let window = make_window_from_structure window_structure "Hello world window" 
        
-let _ = window #connect_delete_event( fun () -> Gtk.main_quit(); false )
+let _ = window #connect_delete_event( fun () -> GtkThr.main_quit(); false )
 
 let say_hello () = hello_label #set_text "Yes, hello!"
     
 let _ = hello_button #connect_clicked say_hello
 
-let _ = quit_button #connect_clicked Gtk.main_quit 
+let _ = quit_button #connect_clicked GtkThr.main_quit 
 
 let _ = window #set_usize 150 250 ;;
   (* This is one of the ways to make the window bigger
