@@ -456,6 +456,8 @@ external file_selection_set_filename : gtkobject -> string -> unit =
   "mlgtk_file_selection_set_filename"
 external file_selection_get_filename : gtkobject -> string =
   "mlgtk_file_selection_get_filename"
+external file_selection_complete : gtkobject -> string -> unit =
+  "mlgtk_file_selection_complete"
 external file_selection_get_ok_button : gtkobject -> gtkobject =
   "mlgtk_file_selection_get_ok_button"
 external file_selection_get_cancel_button : gtkobject -> gtkobject =
@@ -668,24 +670,73 @@ external menu_shell_insert : gtkobject->gtkobject->int->unit = "mlgtk_menu_shell
 external notebook_new : unit -> gtkobject = "mlgtk_notebook_new"
 external notebook_append_page : gtkobject -> gtkobject -> gtkobject -> unit =
   "mlgtk_notebook_append_page"
+external notebook_append_page_menu : gtkobject -> gtkobject -> gtkobject ->
+  gtkobject -> unit = "mlgtk_notebook_append_page_menu"
 external notebook_prepend_page : gtkobject -> gtkobject -> gtkobject -> unit =
   "mlgtk_notebook_prepend_page"
-external notebook_insert_page : gtkobject -> gtkobject -> gtkobject -> int -> unit =
-  "mlgtk_notebook_insert_page"
+external notebook_prepend_page_menu : gtkobject -> gtkobject -> gtkobject ->
+  gtkobject -> unit = "mlgtk_notebook_prepend_page_menu"
+external notebook_insert_page : gtkobject -> gtkobject -> gtkobject ->
+  int -> unit = "mlgtk_notebook_insert_page"
+external notebook_insert_page_menu : gtkobject -> gtkobject -> gtkobject ->
+  gtkobject -> int -> unit = "mlgtk_notebook_insert_page_menu"
 external notebook_remove_page : gtkobject -> int -> unit = 
-"mlgtk_notebook_remove_page"
+  "mlgtk_notebook_remove_page"
+
+external notebook_get_current_page : gtkobject -> int =
+  "mlgtk_notebook_get_current_page"
+external notebook_get_nth_page : gtkobject -> int -> gtkobject =
+  "mlgtk_notebook_get_nth_page"
+external notebook_page_num : gtkobject -> gtkobject -> int =
+  "mlgtk_notebook_page_num"
 external notebook_set_page : gtkobject -> int -> unit =
-"mlgtk_notebook_set_page"
+  "mlgtk_notebook_set_page"
 external notebook_next_page : gtkobject -> unit =
-"mlgtk_notebook_next_page"
+  "mlgtk_notebook_next_page"
 external notebook_prev_page : gtkobject -> unit =
-"mlgtk_notebook_prev_page"
+  "mlgtk_notebook_prev_page"
+
+external notebook_set_show_border : gtkobject -> bool -> unit = 
+  "mlgtk_notebook_set_show_border"
+external notebook_set_show_tabs : gtkobject -> bool -> unit = 
+  "mlgtk_notebook_set_show_tabs"
 external notebook_set_tab_pos : gtkobject -> position_type -> unit =
   "mlgtk_notebook_set_tab_pos"
-external notebook_set_show_tabs : gtkobject -> bool -> unit = 
-"mlgtk_notebook_set_show_tabs"
-external notebook_set_show_border : gtkobject -> bool -> unit = 
-"mlgtk_notebook_set_show_border"
+external notebook_set_homogeneous_tabs : gtkobject -> bool -> unit = 
+  "mlgtk_notebook_set_homogeneous_tabs"
+external notebook_set_tab_border : gtkobject -> int -> unit = 
+  "mlgtk_notebook_set_tab_border"
+external notebook_set_tab_hborder : gtkobject -> int -> unit = 
+  "mlgtk_notebook_set_tab_hborder"
+external notebook_set_tab_vborder : gtkobject -> int -> unit = 
+  "mlgtk_notebook_set_tab_vborder"
+external notebook_set_scrollable : gtkobject -> bool -> unit = 
+  "mlgtk_notebook_set_scrollable"
+
+external notebook_popup_enable : gtkobject -> unit = 
+  "mlgtk_notebook_popup_enable"
+external notebook_popup_disable : gtkobject -> unit = 
+  "mlgtk_notebook_popup_disable"
+
+external notebook_get_tab_label : gtkobject -> gtkobject -> gtkobject = 
+  "mlgtk_notebook_get_tab_label"
+external notebook_set_tab_label : gtkobject -> gtkobject -> gtkobject ->
+  unit = "mlgtk_notebook_set_tab_label"
+external notebook_set_tab_label_text : gtkobject -> gtkobject -> string ->
+  unit = "mlgtk_notebook_set_tab_label_text"
+external notebook_get_menu_label : gtkobject -> gtkobject -> unit = 
+  "mlgtk_notebook_get_menu_label"
+external notebook_set_menu_label : gtkobject -> gtkobject -> gtkobject ->
+  unit = "mlgtk_notebook_set_menu_label"
+external notebook_set_menu_label_text : gtkobject -> gtkobject -> string ->
+  unit = "mlgtk_notebook_set_menu_label_text"
+external notebook_query_tab_label_packing : gtkobject -> gtkobject ->
+   bool*bool*pack_type = "mlgtk_notebook_query_tab_label_packing"
+external notebook_set_tab_label_packing : gtkobject -> gtkobject -> bool ->
+  bool -> pack_type -> unit = "mlgtk_notebook_set_tab_label_packing"
+external notebook_reorder_child : gtkobject -> gtkobject -> int -> unit =
+  "mlgtk_notebook_set_tab_label_packing"
+
 (* NOTEBOOK *)
 (* NOTEBOOK_CLASS *)
 (* IS_NOTEBOOK *)
@@ -848,18 +899,18 @@ external scrolled_window_add_with_viewport : gtkobject -> gtkobject -> unit =
 (* IS_SEPARATOR *)
 
 (* ### 5.57 Statusbar widget *)
-external statusbar_new :unit->gtkobject = "mlgtk_statusbar_new"
-external statusbar_get_context_id :gtkobject->string->int
+external statusbar_new : unit->gtkobject = "mlgtk_statusbar_new"
+external statusbar_get_context_id : gtkobject->string->int
  = "mlgtk_statusbar_get_context_id"
-external statusbar_push :gtkobject->int->string->int = "mlgtk_statusbar_push"
-external statusbar_pop :gtkobject->int->unit = "mlgtk_statusbar_pop"
-external statusbar_remove :gtkobject->int->int->unit = "mlgtk_statusbar_remove"
+external statusbar_push : gtkobject->int->string->int = "mlgtk_statusbar_push"
+external statusbar_pop : gtkobject->int->unit = "mlgtk_statusbar_pop"
+external statusbar_remove : gtkobject->int->int->unit = "mlgtk_statusbar_remove"
 
 (* mask to attach objets in a table *)
 type option_mask =
-    | GTK_FILL
-    | GTK_SHRINK
     | GTK_EXPAND
+    | GTK_SHRINK
+    | GTK_FILL
 
 (* ### 5.58 Table widget *)
 (* table_get_type *)
