@@ -46,7 +46,7 @@ let set_pixmap d width height depth =
 
 (* The configure event takes place at initialization and every time
    the size of the widget changes *)
-let drawingarea_configure c drawingarea x y width height = 
+let drawingarea_configure c drawingarea gtkobject x y width height = 
   let p = set_pixmap drawingarea width height (-1)
   (* The black Graphic Context to fill the empty pixmap *)
   and black_gc = 
@@ -63,7 +63,7 @@ let empty_c drawingarea x y width height = ()
 (* The expose event takes place after each configure event,
    and each time the widget becomes visible again (after having been
    hidden *)
-let drawingarea_expose e drawingarea x y width height =
+let drawingarea_expose e drawingarea gtkobject x y width height =
   try
     let p = get_pixmap drawingarea
     (* The foreground Graphic Context to draw the backing pixmap *)
@@ -81,19 +81,19 @@ let drawingarea_expose e drawingarea x y width height =
 let empty_e drawingarea x y width height = ()
 
 (* Button pressed event *)
-let drawingarea_button_pressed b drawingarea x y button state =
+let drawingarea_button_pressed b drawingarea gtkobject x y button state =
   let () = b drawingarea x y button state
   in true 
 let empty_b drawingarea x y button state = ()
 
 (* Motion notify event *)
-let drawingarea_motion_notify m drawingarea x y is_hint state =
+let drawingarea_motion_notify m drawingarea gtkobject x y is_hint state =
   let () = m drawingarea x y is_hint state
   in true 
 let empty_m drawingarea x y is_hint state = ()
 
 (* Key pressed event *)
-let drawingarea_key_pressed k drawingarea keyval state =
+let drawingarea_key_pressed k drawingarea gtkobject keyval state =
   let () = k drawingarea keyval state
   in true
 let empty_k drawingarea keyval state = ()
@@ -110,13 +110,16 @@ let make_drawing_area c e b m k x y =
 		POINTER_MOTION_MASK;
 		POINTER_MOTION_HINT_MASK;
     ]
-  in let _ = drawingarea#connect_configure (drawingarea_configure c)
-  in let _ = drawingarea#connect_expose (drawingarea_expose e)
+  in let _ = drawingarea#connect_configure
+    (drawingarea_configure c drawingarea)
+  in let _ = drawingarea#connect_expose
+    (drawingarea_expose e drawingarea)
   in let _ = drawingarea#connect_button_press
-    (drawingarea_button_pressed b)
+    (drawingarea_button_pressed b drawingarea)
   in let _ = drawingarea#connect_motion_notify
-    (drawingarea_motion_notify m)
-  in let _ = drawingarea#connect_key_press (drawingarea_key_pressed k)
+    (drawingarea_motion_notify m drawingarea)
+  in let _ = drawingarea#connect_key_press
+    (drawingarea_key_pressed k drawingarea)
   in let _ = drawingarea#size x y
   in drawingarea
 let make_drawing_area_empty x y = make_drawing_area
