@@ -610,6 +610,7 @@ object
   inherit window gtkobject
   method set_filename name = file_selection_set_filename gtkobject name
   method get_filename = file_selection_get_filename gtkobject 
+  method complete name = file_selection_complete gtkobject name
   method get_ok_button =
     new button (file_selection_get_ok_button gtkobject)
   method get_cancel_button =
@@ -621,25 +622,74 @@ object
   inherit widget gtkobject
   method append_page (page : widget) (label : widget) = 
     notebook_append_page gtkobject (page #get_gtkobject) (label #get_gtkobject)
+  method append_page_menu (page : widget) (label : widget) (menu : widget)= 
+    notebook_append_page_menu gtkobject
+    (page #get_gtkobject) (label #get_gtkobject) (menu #get_gtkobject)
   method prepend_page (page : widget) (label : widget) = 
     notebook_prepend_page gtkobject (page #get_gtkobject) 
       (label #get_gtkobject)
+  method prepend_page_menu (page : widget) (label : widget) (menu : widget) = 
+    notebook_prepend_page_menu gtkobject (page #get_gtkobject) 
+      (label #get_gtkobject) (menu #get_gtkobject)
   method insert_page (page : widget) (label : widget) pos = 
     notebook_insert_page gtkobject (page #get_gtkobject) 
       (label #get_gtkobject) pos
+  method insert_page_menu (page : widget) (label : widget) (menu : widget) pos =
+    notebook_insert_page_menu gtkobject (page #get_gtkobject) 
+      (label #get_gtkobject) (menu #get_gtkobject) pos
   method remove_page pos = 
     notebook_remove_page gtkobject pos
-  method set_page pos = 
-    notebook_set_page gtkobject pos
-  method next_page = 
-    notebook_next_page gtkobject 
-  method prev_page = 
-    notebook_prev_page gtkobject 
-  method set_tab_pos pos = notebook_set_tab_pos gtkobject pos
-  method set_show_tabs show_tabs = 
-    notebook_set_show_tabs gtkobject show_tabs		
-  method set_show_border show_border = 
+
+  method get_current_page = notebook_get_current_page gtkobject
+  method get_nth_page page_num = notebook_get_nth_page gtkobject page_num
+  method page_num (page : widget) =
+    notebook_page_num gtkobject (page #get_gtkobject)
+  method set_page pos = notebook_set_page gtkobject pos
+  method next_page = notebook_next_page gtkobject 
+  method prev_page = notebook_prev_page gtkobject 
+
+  method set_show_border show_border =
     notebook_set_show_border gtkobject show_border		
+  method set_show_tabs show_tabs = notebook_set_show_tabs gtkobject show_tabs
+  method set_tab_pos pos = notebook_set_tab_pos gtkobject pos
+  method set_homogeneous_tabs homogeneous_tabs =
+    notebook_set_homogeneous_tabs gtkobject homogeneous_tabs
+  method set_tab_border border_width =
+    notebook_set_tab_border gtkobject border_width
+  method set_tab_hborder tab_hborder =
+    notebook_set_tab_hborder gtkobject tab_hborder
+  method set_tab_vborder tab_vborder =
+    notebook_set_tab_vborder gtkobject tab_vborder
+  method set_scrollable scrollable =
+    notebook_set_scrollable gtkobject scrollable
+
+  method popup_enable =
+    notebook_popup_enable gtkobject
+  method popup_disable =
+    notebook_popup_disable gtkobject
+
+  method get_tab_label (page : widget) = 
+    notebook_get_tab_label gtkobject (page #get_gtkobject)
+  method set_tab_label (page : widget) (tab_label : widget) = 
+    notebook_set_tab_label gtkobject (page #get_gtkobject)
+    (tab_label #get_gtkobject)
+  method set_tab_label_text (page : widget) tab_text = 
+    notebook_set_tab_label_text gtkobject (page #get_gtkobject) tab_text
+  method get_menu_label (page : widget) = 
+    notebook_get_menu_label gtkobject (page #get_gtkobject)
+  method set_menu_label (page : widget) (menu_label : widget) = 
+    notebook_set_menu_label gtkobject (page #get_gtkobject)
+    (menu_label #get_gtkobject)
+  method set_menu_label_text (page : widget) menu_text = 
+    notebook_set_menu_label_text gtkobject (page #get_gtkobject) menu_text
+  method query_tab_label_packing (page : widget) =
+    notebook_query_tab_label_packing gtkobject (page #get_gtkobject)
+  method set_tab_label_packing (page : widget) expand fill pack_type =
+    notebook_set_tab_label_packing gtkobject (page #get_gtkobject)
+    expand fill pack_type
+  method reorder_child (page : widget) position=
+    notebook_reorder_child gtkobject (page #get_gtkobject) position
+
 end
 
 (******* useful function *********)
