@@ -1219,6 +1219,15 @@ value mlgtk_file_selection_set_filename (value FILESEL,
   return Val_unit;
 }
 
+value mlgtk_file_selection_complete (value FILESEL, 
+				       value PATTERN)
+{
+  check_GtkObject_ml(FILESEL, "Gtk.Unsafe.file_selection_complete");
+  gtk_file_selection_complete(GtkFileSelection_ml(FILESEL),
+				  String_val(PATTERN));
+  return Val_unit;
+}
+
 /* gchar* gtk_file_selection_get_filename (GtkFileSelection *FILESEL) */
 value mlgtk_file_selection_get_filename (value FILESEL)
 {
@@ -1610,6 +1619,16 @@ value mlgtk_notebook_append_page(value notebook,value page,value label)
 			   GtkWidget_ml(label));
   return Val_unit;
 }
+value mlgtk_notebook_append_page_menu(value notebook,value page,value label, value menu)
+{
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_append_page_menu");
+  check_GtkObject_ml(page, "Gtk.Unsafe.notebook_append_page_menu");
+  check_GtkObject_ml(label, "Gtk.Unsafe.notebook_append_page_menu");
+  check_GtkObject_ml(menu, "Gtk.Unsafe.notebook_append_page_menu");
+  gtk_notebook_append_page_menu(GtkNotebook_ml(notebook),GtkWidget_ml(page),
+			   GtkWidget_ml(label), GtkWidget_ml(menu));
+  return Val_unit;
+}
 
 value mlgtk_notebook_prepend_page(value notebook,value page,value label)
 {
@@ -1621,6 +1640,16 @@ value mlgtk_notebook_prepend_page(value notebook,value page,value label)
   return Val_unit;
 }
 
+value mlgtk_notebook_prepend_page_menu(value notebook,value page,value label,value menu)
+{
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_prepend_page_menu");
+  check_GtkObject_ml(page, "Gtk.Unsafe.notebook_prepend_page_menu");
+  check_GtkObject_ml(label, "Gtk.Unsafe.notebook_prepend_page_menu");
+  check_GtkObject_ml(menu, "Gtk.Unsafe.notebook_prepend_page_menu");
+  gtk_notebook_prepend_page_menu(GtkNotebook_ml(notebook),GtkWidget_ml(page),
+			   GtkWidget_ml(label), GtkWidget_ml(menu));
+  return Val_unit;
+}
 
 value mlgtk_notebook_insert_page(value notebook,value page,value label,
 				 value pos)
@@ -1632,7 +1661,18 @@ value mlgtk_notebook_insert_page(value notebook,value page,value label,
 			   GtkWidget_ml(label),Int_val(pos));
   return Val_unit;
 }
-
+value mlgtk_notebook_insert_page_menu(value notebook,value page,value label,
+				 value menu, value pos)
+{
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_insert_page_menu");
+  check_GtkObject_ml(page, "Gtk.Unsafe.notebook_insert_page_menu");
+  check_GtkObject_ml(label, "Gtk.Unsafe.notebook_insert_page_menu");
+  check_GtkObject_ml(menu, "Gtk.Unsafe.notebook_insert_page_menu");
+  gtk_notebook_insert_page_menu(GtkNotebook_ml(notebook),GtkWidget_ml(page),
+			   GtkWidget_ml(label),GtkWidget_ml(menu),
+			   Int_val(pos));
+  return Val_unit;
+}
 value mlgtk_notebook_remove_page(value notebook,value page_num)
 {
   check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_remove_page");
@@ -1640,6 +1680,25 @@ value mlgtk_notebook_remove_page(value notebook,value page_num)
   return Val_unit;
 }
 
+value mlgtk_notebook_get_current_page(value notebook)
+{
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_get_current_page");
+  return Val_int(gtk_notebook_get_current_page(GtkNotebook_ml(notebook)));
+}
+
+value mlgtk_notebook_get_nth_page(value notebook, value page_num)
+{
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_get_nth_page");
+  return ml_GtkObject(gtk_notebook_get_nth_page(GtkNotebook_ml(notebook), Int_val(page_num)));
+}
+
+value mlgtk_notebook_page_num(value notebook, value child)
+{
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_page_num");
+  check_GtkObject_ml(child, "Gtk.Unsafe.notebook_page_num");
+  return Val_int(gtk_notebook_page_num(GtkNotebook_ml(notebook),GtkWidget_ml(child)));
+}
+
 value mlgtk_notebook_set_page(value notebook,value page_num)
 {
   check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_set_page");
@@ -1661,10 +1720,10 @@ value mlgtk_notebook_prev_page(value notebook)
   return Val_unit;
 }
 
-value mlgtk_notebook_set_tab_pos(value notebook,value pos)
+value mlgtk_notebook_set_show_border(value notebook,value show_border)
 {
-  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_set_tab_pos");
-  gtk_notebook_set_tab_pos(GtkNotebook_ml(notebook), Int_val(pos));
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_set_show_border");
+  gtk_notebook_set_show_border(GtkNotebook_ml(notebook), Int_val(show_border));
   return Val_unit;
 }
 
@@ -1675,10 +1734,149 @@ value mlgtk_notebook_set_show_tabs(value notebook,value show_tabs)
   return Val_unit;
 }
 
-value mlgtk_notebook_set_show_border(value notebook,value show_border)
+value mlgtk_notebook_set_tab_pos(value notebook,value pos)
 {
-  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_set_show_border");
-  gtk_notebook_set_show_border(GtkNotebook_ml(notebook), Int_val(show_border));
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_set_tab_pos");
+  gtk_notebook_set_tab_pos(GtkNotebook_ml(notebook), Int_val(pos));
+  return Val_unit;
+}
+
+value mlgtk_notebook_set_homogeneous_tabs(value notebook,value homogeneous)
+{
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_set_homogeneous_tabs");
+  gtk_notebook_set_homogeneous_tabs(GtkNotebook_ml(notebook), Int_val(homogeneous));
+  return Val_unit;
+}
+
+value mlgtk_notebook_set_tab_border(value notebook,value border_width)
+{
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_set_tab_border");
+  gtk_notebook_set_tab_border(GtkNotebook_ml(notebook), Int_val(border_width));
+  return Val_unit;
+}
+
+value mlgtk_notebook_set_tab_hborder(value notebook,value tab_hborder)
+{
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_set_tab_hborder");
+  gtk_notebook_set_tab_hborder(GtkNotebook_ml(notebook), Int_val(tab_hborder));
+  return Val_unit;
+}
+
+value mlgtk_notebook_set_tab_vborder(value notebook,value tab_vborder)
+{
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_set_tab_vborder");
+  gtk_notebook_set_tab_vborder(GtkNotebook_ml(notebook), Int_val(tab_vborder));
+  return Val_unit;
+}
+
+value mlgtk_notebook_set_scrollable(value notebook,value scrollable)
+{
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_set_scrollable");
+  gtk_notebook_set_scrollable(GtkNotebook_ml(notebook), Int_val(scrollable));
+  return Val_unit;
+}
+
+value mlgtk_notebook_popup_enable(value notebook)
+{
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_popup_enable");
+  gtk_notebook_popup_enable(GtkNotebook_ml(notebook));
+  return Val_unit;
+}
+
+value mlgtk_notebook_popup_disable(value notebook)
+{
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_popup_disable");
+  gtk_notebook_popup_disable(GtkNotebook_ml(notebook));
+  return Val_unit;
+}
+
+value mlgtk_notebook_get_tab_label(value notebook, value child)
+{
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_get_tab_label");
+  check_GtkObject_ml(child, "Gtk.Unsafe.notebook_get_tab_label");
+  return ml_GtkObject(gtk_notebook_get_tab_label(GtkNotebook_ml(notebook), GtkWidget_ml(child)));
+}
+
+value mlgtk_notebook_set_tab_label(value notebook, value child, value tab_label)
+{
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_set_tab_label");
+  check_GtkObject_ml(child, "Gtk.Unsafe.notebook_set_tab_label");
+  check_GtkObject_ml(tab_label, "Gtk.Unsafe.notebook_set_tab_label");
+  gtk_notebook_set_tab_label(GtkNotebook_ml(notebook),GtkWidget_ml(child), GtkWidget_ml(tab_label));
+  return Val_unit;
+}
+
+value mlgtk_notebook_set_tab_label_text(value notebook, value child,
+		value tab_text)
+{
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_set_tab_label_text");
+  check_GtkObject_ml(child, "Gtk.Unsafe.notebook_set_tab_label_text");
+  gtk_notebook_set_tab_label_text(GtkNotebook_ml(notebook),GtkWidget_ml(child),
+                             String_val(tab_text));
+  return Val_unit;
+}
+
+value mlgtk_notebook_get_menu_label(value notebook, value child)
+{
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_get_menu_label");
+  check_GtkObject_ml(child, "Gtk.Unsafe.notebook_get_menu_label");
+  return ml_GtkObject(gtk_notebook_get_menu_label(GtkNotebook_ml(notebook), GtkWidget_ml(child)));
+}
+
+value mlgtk_notebook_set_menu_label(value notebook, value child, value menu_label)
+{
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_set_menu_label");
+  check_GtkObject_ml(child, "Gtk.Unsafe.notebook_set_menu_label");
+  check_GtkObject_ml(menu_label, "Gtk.Unsafe.notebook_set_menu_label");
+  gtk_notebook_set_menu_label(GtkNotebook_ml(notebook),GtkWidget_ml(child), GtkWidget_ml(menu_label));
+  return Val_unit;
+}
+
+value mlgtk_notebook_set_menu_label_text(value notebook, value child,
+		value menu_text)
+{
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_set_menu_label_text");
+  check_GtkObject_ml(child, "Gtk.Unsafe.notebook_set_menu_label_text");
+  gtk_notebook_set_menu_label_text(GtkNotebook_ml(notebook),GtkWidget_ml(child),
+                             String_val(menu_text));
+  return Val_unit;
+}
+
+/* Not implemented, should put the result in a record or something such ... */
+value mlgtk_notebook_query_tab_label_packing(value notebook, value child)
+{
+  gint expand, fill;
+  GtkPackType pack_type;
+  value r;
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_query_tab_label_packing");
+  check_GtkObject_ml(child, "Gtk.Unsafe.notebook_query_tab_label_packing");
+
+  gtk_notebook_query_tab_label_packing(GtkNotebook_ml(notebook),
+		  GtkWidget_ml(child), &expand, &fill, &pack_type);
+
+  r=alloc_tuple(3);
+  Field(r, 0)= Val_bool(expand);
+  Field(r, 1)= Val_bool(fill);
+  Field(r, 2)= Val_int(pack_type);
+  return r;  
+}
+
+value mlgtk_notebook_set_tab_label_packing(value notebook, value child,
+		value expand, value fill, value pack_type)
+{
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_set_tab_label_packing");
+  check_GtkObject_ml(child, "Gtk.Unsafe.notebook_set_tab_label_packing");
+  gtk_notebook_set_tab_label_packing(GtkNotebook_ml(notebook),GtkWidget_ml(child),
+		  Int_val(expand), Int_val(fill), Int_val(pack_type));
+  return Val_unit;
+}
+
+value mlgtk_notebook_reorder_child(value notebook, value child, value position)
+{
+  check_GtkObject_ml(notebook, "Gtk.Unsafe.notebook_set_tab_label_packing");
+  check_GtkObject_ml(child, "Gtk.Unsafe.notebook_set_tab_label_packing");
+  gtk_notebook_reorder_child(GtkNotebook_ml(notebook),GtkWidget_ml(child),
+		  Int_val(position));
   return Val_unit;
 }
 
@@ -1784,7 +1982,7 @@ gint mlgtk_convert_options(value option)
   gint r=0;
   while (option != Val_int(0))
     {
-      r |= 2<< (Int_val(Field(option,0)));
+      r |= 1<< (Int_val(Field(option,0)));
       option = Field(option, 1);
     }
   return r;
